.. image:: https://img.shields.io/pypi/v/z3c.layer.pagelet.svg
   :target: https://pypi.org/project/z3c.layer.pagelet/
   :alt: Latest Version

.. image:: https://img.shields.io/pypi/pyversions/z3c.layer.pagelet.svg
   :target: https://pypi.org/project/z3c.layer.pagelet/
   :alt: Supported Python versions

.. image:: https://github.com/zopefoundation/z3c.layer.pagelet/actions/workflows/tests.yml/badge.svg
   :target: https://github.com/zopefoundation/z3c.layer.pagelet/actions/workflows/tests.yml
   :alt: Build Status

.. image:: https://coveralls.io/repos/github/zopefoundation/z3c.layer.pagelet/badge.svg
   :target: https://coveralls.io/github/zopefoundation/z3c.layer.pagelet
   :alt: Code Coverage

This package provides a pagelet based layer setup for Zope3.
